summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/sms/smsservice.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/sms/smsservice.h')
-rw-r--r--kopete/protocols/sms/smsservice.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/sms/smsservice.h b/kopete/protocols/sms/smsservice.h
index d448570b..c5ea28ab 100644
--- a/kopete/protocols/sms/smsservice.h
+++ b/kopete/protocols/sms/smsservice.h
@@ -45,11 +45,11 @@ public:
virtual void setAccount(Kopete::Account* account);
/**
* Called when the settings widget has a place to be. @param tqparent is the
* settings widget's tqparent and @param tqlayout is the 2xn grid tqlayout it may
* use.
*/
- virtual void setWidgetContainer(TQWidget* tqparent, TQGridLayout* tqlayout) = 0;
+ virtual void setWidgetContainer(TQWidget* parent, TQGridLayout* tqlayout) = 0;
virtual void send(const Kopete::Message& msg) = 0;
virtual int maxSize() = 0;
@@ -45,11 +45,11 @@ public:
virtual void setAccount(Kopete::Account* account);
/**
- * Called when the settings widget has a place to be. @param tqparent is the
- * settings widget's tqparent and @param tqlayout is the 2xn grid tqlayout it may
+ * Called when the settings widget has a place to be. @param parent is the
+ * settings widget's parent and @param tqlayout is the 2xn grid tqlayout it may
* use.
*/